function [traj_filter]= swift_scheme_extrapolar_points_filter(points, zeta_level, tropo_z, current_date)
% Function to filter the SWIFT simulation data.
% Always filter bottom and top most layer,
% and where H2O ist bigger than 8ppm (tropospheric trajectory),
% and where thje lifetime of Ox is longer than 14 days (DOx regime filter)
% and trajectories inside the polar vortex.
% INPUT:    points  = ATLAS points data structure [number of trajectories]
%           zeta_level = vector of vertical zeta-coordinate (hybrid coord.),
%           containing the vertical levels of the current SWIFT-ATLAS simulation.
%           tropo_z = vector [length points], altitude of tropopause          
%           current_date = matlab date [date vector]
%           
% OUTPUT:   traj_filter = boolean vector [length points], true if
% point is inside the domain
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ind=swift_scheme_get_species_indices;

% Altitude filter
top_bot_filter = points.zeta>zeta_level(2) & points.zeta<zeta_level(end-1) & points.zeta<=900;

% tropospheric trajectories filter
tropo_filter = points.vmr(ind.H2O)<8e-6 & points.z>tropo_z;

% inside polar vortex filter

polar_swift_low = 17820; % lower most SWIFT polar level [m]
polar_swift_top = 27150; % upper must SWIFT polar level [m]
vortex_filter = ~(abs(npv(points.pv, points.theta, 475))>36 & points.z>polar_swift_low & points.z<polar_swift_top);

% filter for trajectories in polar night
%pn_filter = polar_night_trajectories(current_date, points.z, points.latitude);

% DOx Regime filter
daydate = ones(length(points),1)*(datenum(current_date));
z_dox = swift_scheme_extrapolar_dyn_upper_boundary(points.latitude, daydate, 4);
dox_filter = points.z<=z_dox;

% combine sub-filter
traj_filter = top_bot_filter & tropo_filter & vortex_filter & dox_filter;% & ~pn_filter;
