function dataout = swift_scheme_extrapolar_prevent_extrapolation(datain, poly_struct, current_date, lower_or_upper)
% This function identifies outliers in the dataset and can determine
% appropriate DeltaOx values for the outliers. outliers are data points
% outside the domain of definition of the polynomial function.
% INPUT:    datain  = matrix [length data points x 9] containing the 9 basic
%           SWIFT variables at each data point
%           poly_struct = structure containing the extrapolar SWIFT
%           polynomials
%           lower_or_upper = string setting the altitude range of the 
%           stratosphere either: lower | upper | full
%
% OUTPUT:   dataout = matrix [length data points x 9] modified 9 basic
%           SWIFT variables at the outliers
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get current year, month and day
[cyear,cmonth,~]=datevec(current_date);

switch lower_or_upper
    case 'lower'
        % check correct numer of columns of input data
        assert(size(datain,2)==9, 'Error: Input data "datain", has wrong number of columns.');
        domain_monom = poly_struct.dom_dox_monom{cmonth}; 
        domain_monom_coef = poly_struct.dom_dox_monom_coef{cmonth};
        grad_monom = poly_struct.grad_dox_monom{cmonth}; 
        grad_monom_coef = poly_struct.grad_dox_monom_coef{cmonth};
    
    case 'upper'
        % check correct numer of columns of input data
        assert(size(datain,2)==8, 'Error: Input data "datain", has wrong number of columns.');
        domain_monom = poly_struct.dom_ox_monom{cmonth}; 
        domain_monom_coef = poly_struct.dom_ox_monom_coef{cmonth};
        grad_monom = poly_struct.grad_ox_monom{cmonth}; 
        grad_monom_coef = poly_struct.grad_ox_monom_coef{cmonth};
    case 'full'
        % check correct numer of columns of input data
        assert(size(datain,2)==9, 'Error: Input data "datain", has wrong number of columns.');
        domain_monom = poly_struct.dom_dox_monom{cmonth}; 
        domain_monom_coef = poly_struct.dom_dox_monom_coef{cmonth};
        grad_monom = poly_struct.grad_dox_monom{cmonth}; 
        grad_monom_coef = poly_struct.grad_dox_monom_coef{cmonth};
end;

% normalize data
data_norm = swift_scheme_extrapolar_normalize_fitting_data(datain, lower_or_upper);
% apply fit to normalized data
dom_fit = swift_scheme_extrapolar_apply_fit_monoms(data_norm, domain_monom, domain_monom_coef);

% Filter for outside points
fil_out = (dom_fit<0);

% % calculate dox value for outsider points
% dox_fit_tmp = apply_fit_monoms(data_norm(fil_out,:), dox_monom, dox_monom_coef);
% dox_fit = zeros(length(fil_out),1);
% dox_fit(fil_out) = dox_fit_tmp;
% dox_fil = abs(dox_fit)>0.2e-6;

% Filter for points with very high DOx values and outside points
Fx_arr = dom_fit(fil_out);
outsiders = data_norm(fil_out,:);
initial_outsiders = data_norm(fil_out,:);
fprintf('%s Number of outsiders: %i\n', lower_or_upper, length(Fx_arr));

% Loop over all outsiders points and move them back into the domain along
% the gradient of the domain polynom.
for ii = 1:size(outsiders,1)
    current_point = outsiders(ii,:);
    Fx = Fx_arr(ii);
    %fprintf('%i %s Fx: %7.2f - coord:\t%s\n', ii, lower_or_upper, Fx, mat2str(current_point,2));
    while abs(Fx)>0.5
        dx = swift_scheme_extrapolar_calc_gradient(current_point, grad_monom, grad_monom_coef);
        dx = -Fx/(norm(dx)^2)*dx;
        %fprintf('%i dx:\t%s\n', ii, mat2str(dx,2));
        %o = ceil(log10(max(dx)))+2; % get order of step size
        current_point = current_point + dx;        
        % set current_point back to absolute domain, if outside abs domain
        if any(current_point<0) || any(current_point>1)
            current_point(current_point<0) = 0;
            current_point(current_point>1) = 1;
            fprintf('%i: Outsider point was moved outside abs domain! and set back into abs. domain.\n', ii);
        end;
        %fprintf('%i coord:\t%s\n', ii, mat2str(current_point,2));
        Fx = swift_scheme_extrapolar_apply_fit_monoms(current_point, domain_monom, domain_monom_coef);
        %fprintf('%i %s Fx: %7.2f - coord:\t%s\n', ii, lower_or_upper, Fx, mat2str(current_point,2));
        %tmp = apply_fit_monoms(current_point, poly_struct.dox_monom{cmonth}, poly_struct.dox_monom_coef{cmonth});
        %fprintf('%i Fx: %7.2f\tDOx: %7.2g \n', ii, Fx, tmp);
        %if (any(current_point<0) || any(current_point>1)) && abs(Fx)<0.5
            %fprintf('%6.2f', current_point);
            %fprintf('\n');
            %current_point(current_point<0) = 0;
            %current_point(current_point>1) = 1;
            %fprintf('%i: Ousider point was moved outside abs domain! and set back into abs. domain.\n', ii);
            %return;
        %end;
        
    end;
    outsiders(ii,:) = current_point;
end;
% % % ANALYSIS BLOCK
% outname = sprintf('outliers_%s', datestr(current_date, 'yyyymmdd'));
% output = struct('data_norm',data_norm, 'outsider_filter', fil_out,...
%     'diff_outsiders', (outsiders-initial_outsiders), 'Fx', Fx_arr, 'date', current_date);
% path = '/strat1/data/atlas_swift_daniel/swift_extrapol_4th_dc_intermon_lower_ext_dyntop_atlas_cf_MAR16';
% outname = sprintf('%s/outliers/%s', path, outname);
% save(outname, '-v7.3', '-struct', 'output');

% update outsider coordinates
data_norm(fil_out,:) = outsiders;

% denormalize data
dataout = swift_scheme_extrapolar_denormalize_fitting_data(data_norm, lower_or_upper);