function points=swift_scheme_reinit_strato_species_from_daily_atlas(points,eqlat,tropo_z,points_vortex_flag,regime_filter,swift_extra_polar_flag,current_date,ind)
% Interpolate the SWIFT trace gas families (Cly, Bry, NOy, H2O and Ox) from 
% climatologies, where necessary. This function is called once during each
% chemistry time step. 
% DAILY ATLAS MODIFICATION: function adapted to read the trace gas values
% from zonaly averaged daily trace gas fields, derived from 2 specific
% ATLAS simulations. This is a specific setup for a validation simulation
% of SWIFT-ATLAS
%
% INPUT:    points  = ATLAS points data structure [number of trajectories]
%           eqlat = = vector [length points], equivalent latitude for points
%           tropo_z = vector [length points], altitude of tropopause
%           points_vortex_flag = boolean vector [length points], true if
%           point is inside polar vortex
%           regime_filter = boolean vector [length points], true if Ox  
%           lifetime at point is below 14 days
%           swift_extra_polar_flag = boolean flag extrapolar SWIFT on/off 
%           current_date = matlab date [date vector]
%           ind = hard coded indices of SWIFT species (see
%           swift_scheme_get_species_indices.m)
%
%
% OUTPUT:   points = modified ATLAS points data structure [number of trajectories]
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
get_physical_constants;

tropolist=points.z<tropo_z;
stratolist=~tropolist;
% Dynamical tropopause: smaller 2 PVU and smaller 375 K

% Species that are initialized as climatology everywhere in the stratosphere

% Init from daily atlas means
points(stratolist).vmr(ind.H2O)=init_daily_strat_atlas_climatology(points(stratolist),eqlat(stratolist),current_date, 'hoy');

% Init from daily atlas means
points(stratolist).vmr(ind.NOy)=init_daily_strat_atlas_climatology(points(stratolist),eqlat(stratolist),current_date, 'noy');
points(stratolist).vmr(ind.Bry)=init_daily_strat_atlas_climatology(points(stratolist),eqlat(stratolist),current_date, 'bry');

% Now the species that are only initialized outside vortex in the stratosphere
stratolist=stratolist&~points_vortex_flag;

% Init from daily atlas means
if swift_extra_polar_flag 
    % True where the SWIFT extrapolar polynomials are valid
    points_extrapol_flag = stratolist & regime_filter;
    % Set O3 to daily atlas means, where SWIFT extrapolar did NOT calculate
    points(~points_extrapol_flag).vmr(ind.O3)=init_daily_strat_atlas_climatology(points(~points_extrapol_flag),eqlat(~points_extrapol_flag),current_date, 'ox');

    % Nudging of daily atlas means and DOx regime
    points(points_extrapol_flag).vmr(ind.O3) = swift_scheme_extrapolar_clim_nudging(points(points_extrapol_flag),eqlat(points_extrapol_flag),current_date,ind);
else
    % only if extrapolar module is off
    points(stratolist).vmr(ind.O3)=init_daily_strat_atlas_climatology(points(stratolist),eqlat(stratolist),current_date, 'ox');

end;
points(stratolist).vmr(ind.HNO3)=init_hno3_strat_mls_climatology(points(stratolist),eqlat(stratolist),current_date);

% Init from daily atlas means
points(stratolist).vmr(ind.Cly)=init_daily_strat_atlas_climatology(points(stratolist),eqlat(stratolist),current_date, 'cly');
points(stratolist).vmr(ind.HCl)=init_hcl_strat_swift_climatology(points(stratolist),eqlat(stratolist),current_date);
points(stratolist).vmr(ind.ClONO2)=init_clono2_strat_swift_climatology(points(stratolist),eqlat(stratolist),current_date);

% Make sure that sum of HCl and ClONO2 is always smaller than Cly
% If Cly is bigger, that is no problem, that means ClOx is there
list=(points.vmr(ind.ClONO2)+points.vmr(ind.HCl))>points.vmr(ind.Cly);
points(list).vmr(ind.ClONO2)=points(list).vmr(ind.Cly)-points(list).vmr(ind.HCl);
% Probably will not happen, would mean HCl>Cly
list=points.vmr(ind.ClONO2)<0;
points(list).vmr(ind.ClONO2)=0;

% This method only works when Cly only consists of HCl and ClONO2 and goes very wrong if there is ClOx
%points(stratolist).vmr(ind.ClONO2)=points(stratolist).vmr(ind.Cly)-points(stratolist).vmr(ind.HCl);
%list=points.vmr(ind.ClONO2)<0;
%points(list).vmr(ind.ClONO2)=0;

% Scale with EESC
% Commented for SWIFT extrapolar. polynomials have not been fitted with
% EESC scaling.
% eesc=load_eesc(5);
% index=find(eesc.time<=current_date,1,'last');
% eesc_now=eesc.vmr(index)+(eesc.vmr(index+1)-eesc.vmr(index))./(eesc.time(index+1)-eesc.time(index))*(current_date-eesc.time(index));
% scale_factor=eesc_now./max(eesc.vmr);
% points(stratolist).vmr(ind.Cly)=scale_factor.*points(stratolist).vmr(ind.Cly);
% points(stratolist).vmr(ind.HCl)=scale_factor.*points(stratolist).vmr(ind.HCl);
% points(stratolist).vmr(ind.ClONO2)=scale_factor.*points(stratolist).vmr(ind.ClONO2);


points(tropolist).vmr=0;
points(tropolist).vmr(ind.H2O)=init_h2o_tropo_rh(points(tropolist),current_date);